@@ -10,4 +10,6 @@ from .submittals import *
 from .tasks import *
 from .cost_codes import *
 from .time import *
-from .quality import *
\ No newline at end of file
+from .quality import *
+from .photos import *
+from .permissions import *
